@@ -1,5 +1,5 @@
-//!error system
-use std::{error, fmt, io, num, str};
+//! error system used around the library.
+use std::{error, fmt, io, num, str, sync::mpsc};
 
 #[derive(Debug, PartialEq)]
 pub enum ParseErr {
@@ -10,8 +10,6 @@ pub enum ParseErr {
     UriErr,
     Invalid,
     Empty,
-    #[cfg(feature = "rust-tls")]
-    Rustls(rustls::Error),
 }
 
 impl error::Error for ParseErr {
@@ -22,8 +20,6 @@ impl error::Error for ParseErr {
             Utf8(e) => Some(e),
             Int(e) => Some(e),
             StatusErr | HeadersErr | UriErr | Invalid | Empty => None,
-            #[cfg(feature = "rust-tls")]
-            Rustls(e) => Some(e),
         }
     }
 }
@@ -33,27 +29,18 @@ impl fmt::Display for ParseErr {
         use self::ParseErr::*;
 
         let err = match self {
-            Utf8(_) => "invalid character",
-            Int(_) => "cannot parse number",
-            Invalid => "invalid value",
-            Empty => "nothing to parse",
-            StatusErr => "status line contains invalid values",
-            HeadersErr => "headers contain invalid values",
-            UriErr => "uri contains invalid characters",
-            #[cfg(feature = "rust-tls")]
-            Rustls(_) => "rustls error",
+            Utf8(_) => "Invalid character",
+            Int(_) => "Cannot parse number",
+            Invalid => "Invalid value",
+            Empty => "Nothing to parse",
+            StatusErr => "Status line contains invalid values",
+            HeadersErr => "Headers contain invalid values",
+            UriErr => "URI contains invalid characters",
         };
         write!(f, "ParseErr: {}", err)
     }
 }
 
-#[cfg(feature = "rust-tls")]
-impl From<rustls::Error> for ParseErr {
-    fn from(e: rustls::Error) -> Self {
-        ParseErr::Rustls(e)
-    }
-}
-
 impl From<num::ParseIntError> for ParseErr {
     fn from(e: num::ParseIntError) -> Self {
         ParseErr::Int(e)
@@ -70,7 +57,9 @@ impl From<str::Utf8Error> for ParseErr {
 pub enum Error {
     IO(io::Error),
     Parse(ParseErr),
+    Timeout,
     Tls,
+    Thread,
 }
 
 impl error::Error for Error {
@@ -80,7 +69,7 @@ impl error::Error for Error {
         match self {
             IO(e) => Some(e),
             Parse(e) => Some(e),
-            Tls => None,
+            Timeout | Tls | Thread => None,
         }
     }
 }
@@ -91,27 +80,15 @@ impl fmt::Display for Error {
 
         let err = match self {
             IO(_) => "IO error",
-            Tls => "TLS error",
             Parse(err) => return err.fmt(f),
+            Timeout => "Timeout error",
+            Tls => "TLS error",
+            Thread => "Thread communication error",
         };
         write!(f, "Error: {}", err)
     }
 }
 
-#[cfg(feature = "native-tls")]
-impl From<native_tls::Error> for Error {
-    fn from(_e: native_tls::Error) -> Self {
-        Error::Tls
-    }
-}
-
-#[cfg(feature = "native-tls")]
-impl<T> From<native_tls::HandshakeError<T>> for Error {
-    fn from(_e: native_tls::HandshakeError<T>) -> Self {
-        Error::Tls
-    }
-}
-
 impl From<io::Error> for Error {
     fn from(e: io::Error) -> Self {
         Error::IO(e)
@@ -129,3 +106,36 @@ impl From<str::Utf8Error> for Error {
         Error::Parse(ParseErr::Utf8(e))
     }
 }
+
+impl From<mpsc::RecvTimeoutError> for Error {
+    fn from(_e: mpsc::RecvTimeoutError) -> Self {
+        Error::Timeout
+    }
+}
+
+#[cfg(feature = "rust-tls")]
+impl From<rustls::Error> for Error {
+    fn from(_e: rustls::Error) -> Self {
+        Error::Tls
+    }
+}
+
+#[cfg(feature = "native-tls")]
+impl From<native_tls::Error> for Error {
+    fn from(_e: native_tls::Error) -> Self {
+        Error::Tls
+    }
+}
+
+#[cfg(feature = "native-tls")]
+impl<T> From<native_tls::HandshakeError<T>> for Error {
+    fn from(_e: native_tls::HandshakeError<T>) -> Self {
+        Error::Tls
+    }
+}
+
+impl<T> From<mpsc::SendError<T>> for Error {
+    fn from(_e: mpsc::SendError<T>) -> Self {
+        Error::Thread
+    }
+}
