@@ -1,4 +1,4 @@
-//!secure connection over TLS
+//! secure connection over TLS
 
 use crate::error::Error as HttpError;
 use std::{
@@ -11,13 +11,17 @@ use std::{
 use std::io::prelude::*;
 
 #[cfg(feature = "rust-tls")]
-use crate::error::ParseErr;
+use rustls::{ClientConnection, StreamOwned};
+#[cfg(feature = "rust-tls")]
+use rustls_pki_types::ServerName;
 
 #[cfg(not(any(feature = "native-tls", feature = "rust-tls")))]
 compile_error!("one of the `native-tls` or `rust-tls` features must be enabled");
 
-///wrapper around TLS Stream,
-///depends on selected TLS library
+/// Wrapper around TLS Stream, depends on selected TLS library:
+/// - native_tls: `TlsStream<S>`
+/// - rustls: `StreamOwned<ClientConnection, S>`
+#[derive(Debug)]
 pub struct Conn<S: io::Read + io::Write> {
     #[cfg(feature = "native-tls")]
     stream: native_tls::TlsStream<S>,
@@ -26,7 +30,25 @@ pub struct Conn<S: io::Read + io::Write> {
     stream: rustls::StreamOwned<rustls::ClientConnection, S>,
 }
 
-impl<S: io::Read + io::Write> io::Read for Conn<S> {
+impl<S> Conn<S>
+where
+    S: io::Read + io::Write,
+{
+    /// Returns a reference to the underlying socket.
+    pub fn get_ref(&self) -> &S {
+        self.stream.get_ref()
+    }
+
+    /// Returns a mutable reference to the underlying socket.
+    pub fn get_mut(&mut self) -> &mut S {
+        self.stream.get_mut()
+    }
+}
+
+impl<S> io::Read for Conn<S>
+where
+    S: io::Read + io::Write,
+{
     fn read(&mut self, buf: &mut [u8]) -> Result<usize, io::Error> {
         let len = self.stream.read(buf);
 
@@ -49,7 +71,10 @@ impl<S: io::Read + io::Write> io::Read for Conn<S> {
     }
 }
 
-impl<S: io::Read + io::Write> io::Write for Conn<S> {
+impl<S> io::Write for Conn<S>
+where
+    S: io::Read + io::Write,
+{
     fn write(&mut self, buf: &[u8]) -> Result<usize, io::Error> {
         self.stream.write(buf)
     }
@@ -58,7 +83,7 @@ impl<S: io::Read + io::Write> io::Write for Conn<S> {
     }
 }
 
-///client configuration
+/// Client configuration for TLS connection.
 pub struct Config {
     #[cfg(feature = "native-tls")]
     extra_root_certs: Vec<native_tls::Certificate>,
@@ -76,14 +101,10 @@ impl Default for Config {
 
     #[cfg(feature = "rust-tls")]
     fn default() -> Self {
-        let mut root_store = rustls::RootCertStore::empty();
-        root_store.add_trust_anchors(webpki_roots::TLS_SERVER_ROOTS.iter().map(|ta| {
-            rustls::OwnedTrustAnchor::from_subject_spki_name_constraints(
-                ta.subject,
-                ta.spki,
-                ta.name_constraints,
-            )
-        }));
+        let root_store = rustls::RootCertStore {
+            roots: webpki_roots::TLS_SERVER_ROOTS.iter().cloned().collect(),
+        };
+
         Config {
             root_certs: std::sync::Arc::new(root_store),
         }
@@ -91,25 +112,30 @@ impl Default for Config {
 }
 
 impl Config {
+    /// Adds root certificates (X.509) from PEM file.
     #[cfg(feature = "native-tls")]
     pub fn add_root_cert_file_pem(&mut self, file_path: &Path) -> Result<&mut Self, HttpError> {
         let f = File::open(file_path)?;
         let f = BufReader::new(f);
         let mut pem_crt = vec![];
+
         for line in f.lines() {
             let line = line?;
             let is_end_cert = line.contains("-----END");
             pem_crt.append(&mut line.into_bytes());
             pem_crt.push(b'\n');
+
             if is_end_cert {
                 let crt = native_tls::Certificate::from_pem(&pem_crt)?;
                 self.extra_root_certs.push(crt);
                 pem_crt.clear();
             }
         }
+
         Ok(self)
     }
 
+    /// Establishes a secure connection.
     #[cfg(feature = "native-tls")]
     pub fn connect<H, S>(&self, hostname: H, stream: S) -> Result<Conn<S>, HttpError>
     where
@@ -117,41 +143,59 @@ impl Config {
         S: io::Read + io::Write,
     {
         let mut connector_builder = native_tls::TlsConnector::builder();
+
         for crt in self.extra_root_certs.iter() {
             connector_builder.add_root_certificate((*crt).clone());
         }
+
         let connector = connector_builder.build()?;
         let stream = connector.connect(hostname.as_ref(), stream)?;
 
         Ok(Conn { stream })
     }
 
+    /// Adds root certificates (X.509) from a PEM file.
     #[cfg(feature = "rust-tls")]
     pub fn add_root_cert_file_pem(&mut self, file_path: &Path) -> Result<&mut Self, HttpError> {
         let f = File::open(file_path)?;
         let mut f = BufReader::new(f);
+
         let root_certs = std::sync::Arc::make_mut(&mut self.root_certs);
-        root_certs.add_parsable_certificates(&rustls_pemfile::certs(&mut f)?);
+        let mut file_certs = Vec::new();
+
+        for cert in rustls_pemfile::certs(&mut f) {
+            match cert {
+                Ok(item) => {
+                    file_certs.push(item);
+                }
+                Err(e) => return Err(HttpError::IO(e)),
+            }
+        }
+
+        root_certs.add_parsable_certificates(file_certs);
+
         Ok(self)
     }
 
+    /// Establishes a secure connection.
     #[cfg(feature = "rust-tls")]
     pub fn connect<H, S>(&self, hostname: H, stream: S) -> Result<Conn<S>, HttpError>
     where
         H: AsRef<str>,
         S: io::Read + io::Write,
     {
-        use rustls::{ClientConnection, StreamOwned};
+        let hostname = hostname.as_ref().to_string();
 
         let client_config = rustls::ClientConfig::builder()
-            .with_safe_defaults()
             .with_root_certificates(self.root_certs.clone())
             .with_no_client_auth();
+
         let session = ClientConnection::new(
             std::sync::Arc::new(client_config),
-            hostname.as_ref().try_into().map_err(|_| HttpError::Tls)?,
+            ServerName::try_from(hostname).map_err(|_| HttpError::Tls)?,
         )
-        .map_err(|e| ParseErr::Rustls(e))?;
+        .map_err(|_| HttpError::Tls)?;
+
         let stream = StreamOwned::new(session, stream);
 
         Ok(Conn { stream })
