@@ -11,7 +11,7 @@ use std::{
 const HTTP_PORT: u16 = 80;
 const HTTPS_PORT: u16 = 443;
 
-///A (half-open) range bounded inclusively below and exclusively above (start..end) with `Copy`.
+/// A (half-open) range bounded inclusively below and exclusively above (start..end) with `Copy`.
 #[derive(Copy, Clone, Debug, PartialOrd, PartialEq)]
 pub struct RangeC {
     pub start: usize,
@@ -19,14 +19,14 @@ pub struct RangeC {
 }
 
 impl RangeC {
-    ///Creates new `RangeC` with `start` and `end`.
+    /// Creates new `RangeC` with `start` and `end`.
     ///
-    ///# Exmaples
-    ///```
-    ///use http_req::uri::RangeC;
+    /// # Exmaples
+    /// ```
+    /// use http_req::uri::RangeC;
     ///
-    ///const range: RangeC = RangeC::new(0, 20);
-    ///```
+    /// const range: RangeC = RangeC::new(0, 20);
+    /// ```
     pub const fn new(start: usize, end: usize) -> RangeC {
         RangeC { start, end }
     }
@@ -59,16 +59,16 @@ impl Index<RangeC> for String {
     }
 }
 
-///Representation of Uniform Resource Identifier
+/// Representation of Uniform Resource Identifier
 ///
-///# Example
-///```
-///use http_req::uri::Uri;
-///use std::convert::TryFrom;
+/// # Example
+/// ```
+/// use http_req::uri::Uri;
+/// use std::convert::TryFrom;
 ///
-///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-///assert_eq!(uri.host(), Some("foo.com"));
-///```
+/// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+/// assert_eq!(uri.host(), Some("foo.com"));
+/// ```
 #[derive(Clone, Debug, PartialEq)]
 pub struct Uri<'a> {
     inner: &'a str,
@@ -80,58 +80,63 @@ pub struct Uri<'a> {
 }
 
 impl<'a> Uri<'a> {
-    ///Returns scheme of this `Uri`.
+    /// Returns a reference to the underlying &str.
+    pub fn get_ref(&self) -> &str {
+        self.inner
+    }
+
+    /// Returns scheme of this `Uri`.
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.scheme(), "https");
-    ///```
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.scheme(), "https");
+    /// ```
     pub fn scheme(&self) -> &str {
         &self.inner[self.scheme]
     }
 
-    ///Returns information about the user included in this `Uri`.
-    ///     
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns information about the user included in this `Uri`.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.user_info(), Some("user:info"));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.user_info(), Some("user:info"));
+    /// ```
     pub fn user_info(&self) -> Option<&str> {
         self.authority.as_ref().and_then(|a| a.user_info())
     }
 
-    ///Returns host of this `Uri`.
-    ///     
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns host of this `Uri`.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.host(), Some("foo.com"));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.host(), Some("foo.com"));
+    /// ```
     pub fn host(&self) -> Option<&str> {
         self.authority.as_ref().map(|a| a.host())
     }
 
-    ///Returns host of this `Uri` to use in a header.
-    ///     
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns host of this `Uri` to use in a header.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.host_header(), Some("foo.com:12".to_string()));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.host_header(), Some("foo.com:12".to_string()));
+    /// ```
     pub fn host_header(&self) -> Option<String> {
         self.host().map(|h| match self.corr_port() {
             HTTP_PORT | HTTPS_PORT => h.to_string(),
@@ -139,31 +144,31 @@ impl<'a> Uri<'a> {
         })
     }
 
-    ///Returns port of this `Uri`
-    ///     
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns port of this `Uri`
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.port(), Some(12));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.port(), Some(12));
+    /// ```
     pub fn port(&self) -> Option<u16> {
         self.authority.as_ref().and_then(|a| a.port())
     }
 
-    ///Returns port corresponding to this `Uri`.
-    ///Returns default port if it hasn't been set in the uri.
-    ///  
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns port corresponding to this `Uri`.
+    /// Returns default port if it hasn't been set in the uri.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.corr_port(), 12);
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.corr_port(), 12);
+    /// ```
     pub fn corr_port(&self) -> u16 {
         let default_port = match self.scheme() {
             "https" => HTTPS_PORT,
@@ -176,64 +181,133 @@ impl<'a> Uri<'a> {
         }
     }
 
-    ///Returns path of this `Uri`.
-    ///  
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns path of this `Uri`.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.path(), Some("/bar/baz"));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.path(), Some("/bar/baz"));
+    /// ```
     pub fn path(&self) -> Option<&str> {
         self.path.map(|r| &self.inner[r])
     }
 
-    ///Returns query of this `Uri`.
-    ///  
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns query of this `Uri`.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.query(), Some("query"));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.query(), Some("query"));
+    /// ```
     pub fn query(&self) -> Option<&str> {
         self.query.map(|r| &self.inner[r])
     }
 
-    ///Returns fragment of this `Uri`.
-    ///  
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns fragment of this `Uri`.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.fragment(), Some("fragment"));
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.fragment(), Some("fragment"));
+    /// ```
     pub fn fragment(&self) -> Option<&str> {
         self.fragment.map(|r| &self.inner[r])
     }
 
-    ///Returns resource `Uri` points to.
-    ///  
-    ///# Example
-    ///```
-    ///use http_req::uri::Uri;
-    ///use std::convert::TryFrom;
+    /// Returns resource `Uri` points to.
     ///
-    ///let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
-    ///assert_eq!(uri.resource(), "/bar/baz?query#fragment");
-    ///```
+    /// # Example
+    /// ```
+    /// use http_req::uri::Uri;
+    /// use std::convert::TryFrom;
+    ///
+    /// let uri: Uri = Uri::try_from("https://user:info@foo.com:12/bar/baz?query#fragment").unwrap();;
+    /// assert_eq!(uri.resource(), "/bar/baz?query#fragment");
+    /// ```
     pub fn resource(&self) -> &str {
         match self.path {
             Some(p) => &self.inner[p.start..],
             None => "/",
         }
     }
+
+    /// Checks if &str is a relative uri.
+    pub fn is_relative(raw_uri: &str) -> bool {
+        raw_uri.starts_with("/")
+            || raw_uri.starts_with("?")
+            || raw_uri.starts_with("#")
+            || !raw_uri.contains(":")
+    }
+
+    /// Creates a new `Uri` from current uri and relative uri.
+    /// Transforms the relative uri into an absolute uri.
+    pub fn from_relative(&'a self, relative_uri: &'a mut String) -> Result<Uri<'a>, Error> {
+        let inner_uri = self.inner;
+        let mut resource = self.resource().to_string();
+
+        resource = match &relative_uri.get(..1) {
+            Some("#") => Uri::add_part_start(&resource, relative_uri, "#"),
+            Some("?") => Uri::add_part_start(&self.path().unwrap_or("/"), relative_uri, "?"),
+            Some("/") => Uri::add_part_start(&resource, relative_uri, "/"),
+            Some(_) | None => Uri::add_part_end(&resource, relative_uri, "/"),
+        };
+
+        *relative_uri = if let Some(p) = self.path {
+            inner_uri[..p.start].to_string() + &resource
+        } else {
+            inner_uri.trim_end_matches("/").to_string() + &resource
+        };
+
+        Uri::try_from(relative_uri.as_str())
+    }
+
+    /// Adds a part at the beggining of the base.
+    /// Finds the first occurance of a separator in a base and the first occurance of a separator in a part.
+    /// Joins all chars before the separator from the base, separator and all chars after the separator from the part.
+    fn add_part_start(base: &str, part: &str, separator: &str) -> String {
+        let base_idx = base.find(separator);
+        Uri::add_part(base, part, separator, base_idx)
+    }
+
+    /// Adds a part at the end of the base.
+    /// Finds the last occurance of a separator in a base and the first occurance of a separator in a part.
+    /// Joins all chars before the separator from the base, separator and all chars after the separator from the part.
+    fn add_part_end(base: &str, part: &str, separator: &str) -> String {
+        let base_idx = base.rfind(separator);
+        Uri::add_part(base, part, separator, base_idx)
+    }
+
+    /// Adds a part to the base with separator in between.
+    /// Base index defines where part should be added.
+    fn add_part(base: &str, part: &str, separator: &str, base_idx: Option<usize>) -> String {
+        let mut output = String::new();
+        let part_idx = part.find(separator);
+
+        if let Some(idx) = base_idx {
+            output += &base[..idx];
+        } else {
+            output += base;
+        }
+
+        output += separator;
+
+        if let Some(idx) = part_idx {
+            output += &part[idx + 1..];
+        } else {
+            output += part;
+        }
+
+        output
+    }
 }
 
 impl<'a> fmt::Display for Uri<'a> {
@@ -301,16 +375,16 @@ impl<'a> TryFrom<&'a str> for Uri<'a> {
     }
 }
 
-///Authority of Uri
+/// Authority of Uri
 ///
-///# Example
-///```
-///use http_req::uri::Authority;
-///use std::convert::TryFrom;
+/// # Example
+/// ```
+/// use http_req::uri::Authority;
+/// use std::convert::TryFrom;
 ///
-///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-///assert_eq!(auth.host(), "foo.com");
-///```
+/// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+/// assert_eq!(auth.host(), "foo.com");
+/// ```
 #[derive(Clone, Debug, PartialEq)]
 pub struct Authority<'a> {
     inner: &'a str,
@@ -321,44 +395,44 @@ pub struct Authority<'a> {
 }
 
 impl<'a> Authority<'a> {
-    ///Returns username of this `Authority`
+    /// Returns username of this `Authority`
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Authority;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Authority;
+    /// use std::convert::TryFrom;
     ///
-    ///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-    ///assert_eq!(auth.username(), Some("user"));
-    ///```
+    /// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+    /// assert_eq!(auth.username(), Some("user"));
+    /// ```
     pub fn username(&self) -> Option<&'a str> {
         self.username.map(|r| &self.inner[r])
     }
 
-    ///Returns password of this `Authority`
+    /// Returns password of this `Authority`
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Authority;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Authority;
+    /// use std::convert::TryFrom;
     ///
-    ///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-    ///assert_eq!(auth.password(), Some("info"));
-    ///```
+    /// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+    /// assert_eq!(auth.password(), Some("info"));
+    /// ```
     pub fn password(&self) -> Option<&str> {
         self.password.map(|r| &self.inner[r])
     }
 
-    ///Returns information about the user
+    /// Returns information about the user
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Authority;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Authority;
+    /// use std::convert::TryFrom;
     ///
-    ///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-    ///assert_eq!(auth.user_info(), Some("user:info"));
-    ///```
+    /// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+    /// assert_eq!(auth.user_info(), Some("user:info"));
+    /// ```
     pub fn user_info(&self) -> Option<&str> {
         match (&self.username, &self.password) {
             (Some(u), Some(p)) => Some(&self.inner[u.start..p.end]),
@@ -367,30 +441,30 @@ impl<'a> Authority<'a> {
         }
     }
 
-    ///Returns host of this `Authority`
+    /// Returns host of this `Authority`
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Authority;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Authority;
+    /// use std::convert::TryFrom;
     ///
-    ///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-    ///assert_eq!(auth.host(), "foo.com");
-    ///```
+    /// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+    /// assert_eq!(auth.host(), "foo.com");
+    /// ```
     pub fn host(&self) -> &str {
         &self.inner[self.host]
     }
 
-    ///Returns port of this `Authority`
+    /// Returns port of this `Authority`
     ///
-    ///# Example
-    ///```
-    ///use http_req::uri::Authority;
-    ///use std::convert::TryFrom;
+    /// # Example
+    /// ```
+    /// use http_req::uri::Authority;
+    /// use std::convert::TryFrom;
     ///
-    ///let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
-    ///assert_eq!(auth.port(), Some(443));
-    ///```
+    /// let auth: Authority = Authority::try_from("user:info@foo.com:443").unwrap();
+    /// assert_eq!(auth.port(), Some(443));
+    /// ```
     pub fn port(&self) -> Option<u16> {
         self.port.as_ref().map(|p| self.inner[*p].parse().unwrap())
     }
@@ -450,14 +524,14 @@ impl<'a> fmt::Display for Authority<'a> {
     }
 }
 
-//Removes whitespace from `text`
+/// Removes whitespace from `text`
 pub fn remove_spaces(text: &mut String) {
     text.retain(|c| !c.is_whitespace());
 }
 
-//Splits `s` by `separator`. If `separator` is found inside `s`, it will return two `Some` values
-//consisting `RangeC` of each `&str`. If `separator` is at the end of `s` or it's not found,
-//it will return tuple consisting `Some` with `RangeC` of entire `s` inside and None.
+/// Splits `s` by `separator`. If `separator` is found inside `s`, it will return two `Some` values
+/// consisting `RangeC` of each `&str`. If `separator` is at the end of `s` or it's not found,
+/// it will return tuple consisting `Some` with `RangeC` of entire `s` inside and None.
 fn get_chunks<'a>(
     s: &'a str,
     range: Option<RangeC>,
@@ -504,6 +578,16 @@ mod tests {
         "[4b10:bbb0:0:d0::ba7:8001]:443",
     ];
 
+    const TEST_PARTS: [&str; 7] = [
+        "?query123",
+        "/path",
+        "#fragment",
+        "other-path",
+        "#paragraph",
+        "./foo/bar/buz",
+        "?users#1551",
+    ];
+
     #[test]
     fn remove_space() {
         let mut text = String::from("Hello World     !");
@@ -722,6 +806,87 @@ mod tests {
         }
     }
 
+    #[test]
+    fn uri_is_relative() {
+        for i in 0..TEST_URIS.len() {
+            assert!(!Uri::is_relative(TEST_URIS[i]));
+        }
+
+        for i in 0..TEST_PARTS.len() {
+            assert!(Uri::is_relative(TEST_PARTS[i]));
+        }
+    }
+
+    #[test]
+    fn uri_from_relative() {
+        let uris: Vec<_> = TEST_URIS
+            .iter()
+            .map(|&uri| Uri::try_from(uri).unwrap())
+            .collect();
+
+        const RESULT: [&str; 7] = [
+            "https://user:info@foo.com:12/bar/baz?query123",
+            "file:///path",
+            "https://en.wikipedia.org/wiki/Hypertext_Transfer_Protocol#fragment",
+            "mailto:John.Doe@example.com/other-path",
+            "https://[4b10:bbb0:0:d0::ba7:8001]:443/#paragraph",
+            "http://example.com/foo/bar/buz",
+            "https://example.com/?users#1551",
+        ];
+
+        for i in 0..RESULT.len() {
+            let mut uri_part = TEST_PARTS[i].to_string();
+
+            println!("{}", uris[i].resource());
+            assert_eq!(
+                uris[i].from_relative(&mut uri_part).unwrap().inner,
+                RESULT[i]
+            );
+        }
+    }
+
+    #[test]
+    fn uri_add_part() {
+        const BASES: [&str; 2] = ["/bar/baz/fizz?query", "/bar/baz?query#some-fragment"];
+        const RESULT: [&str; 2] = [
+            "/bar/baz/fizz?query#another-fragment",
+            "/bar/baz?query#some-fragment#another-fragment",
+        ];
+
+        for i in 0..BASES.len() {
+            assert_eq!(
+                Uri::add_part(BASES[i], "#another-fragment", "#", Some(BASES[i].len())),
+                RESULT[i]
+            );
+        }
+    }
+
+    #[test]
+    fn uri_add_part_start() {
+        const BASES: [&str; 2] = ["/bar/baz/fizz?query", "/bar/baz?query#some-fragment"];
+        const RESULT: [&str; 2] = [
+            "/bar/baz/fizz?query#another-fragment",
+            "/bar/baz?query#another-fragment",
+        ];
+
+        for i in 0..BASES.len() {
+            assert_eq!(
+                Uri::add_part_start(BASES[i], "#another-fragment", "#"),
+                RESULT[i]
+            );
+        }
+    }
+
+    #[test]
+    fn uri_add_part_end() {
+        const BASES: [&str; 2] = ["/bar/baz/fizz?query", "/bar/baz?query#some-fragment"];
+        const RESULT: [&str; 2] = ["/bar/baz/another", "/bar/another"];
+
+        for i in 0..BASES.len() {
+            assert_eq!(Uri::add_part_end(BASES[i], "./another", "/"), RESULT[i]);
+        }
+    }
+
     #[test]
     fn uri_display() {
         let uris: Vec<_> = TEST_URIS
